@@ -13,7 +13,7 @@ from tuxput.resources import (
 from tuxput.config import TuxConfig
 import json
 
-__version__ = "0.0.3"
+__version__ = "0.0.5"
 
 
 def create_app():
@@ -47,15 +47,21 @@ def create_app():
                 403,
             )
 
-        if requested_bucket is None:
-            requested_bucket = config.DEFAULT_BUCKET
-
         # check that the bucket exists in our config
         # and get a TuxPutBucket obj
         bucket = verify_bucket(
             auth_handler, requested_bucket, config.CONF_FILE
         )
         if bucket is None:
+
+            # if there's more than one bucket in the tuxput.json,
+            # the user is required to specify a bucket.  If there's
+            # only one, then verify_bucket will return it if
+            # requested_bucket was None
+            if requested_bucket is None:
+                return ("Please specify a bucket to upload to", 404)
+
+            # So, they asked for a bucket, we just don't have it.
             return (
                 "Requested upload bucket not found '%s'" % requested_bucket,
                 404,
