@@ -89,21 +89,47 @@ class s3_server:
             OutputSerialization={"JSON": {"RecordDelimiter": "\n"}},
         )
 
+        results = []
         for item in response["Payload"]:
             if "Records" in item:
-                return [
-                    json.loads(x) for x in item["Records"]["Payload"].split()
-                ]
+                record_string = ""
+                for x in item["Records"]["Payload"].decode("utf-8").split():
+                    record_string += x
+                print("item: %s" % record_string)
+                record = json.loads(record_string)
+                print("adding record: %s" % record)
+                results.append(record)
+        return results
 
 
 # searches the tuxput.json for a bucket entry with the specified name
 def verify_bucket(s3_handler, bucket, key):
-    exp = (
-        """SELECT * from S3Object[*].buckets[*] b where b.name = '%s'"""
-        % bucket
-    )
-    result = s3_handler.select_from_json(exp, key).pop()
-    return TuxPutBucket(result)
+
+    # If user doesn't specify a bucket and there's only one bucket
+    # in the json file, we return it.  Else, return None and force
+    # them to specify one.
+    #
+    # If they did specify a bucket, then look for it in our json
+    if bucket is None:
+        exp = """SELECT b.name from S3Object[*].buckets[*] b"""
+    else:
+        exp = (
+            """SELECT * from S3Object[*].buckets[*] b where b.name = '%s'"""
+            % bucket
+        )
+    buckets = s3_handler.select_from_json(exp, key)
+
+    if bucket is None:
+        # If and only if one bucket, then return it as defaul
+        if len(buckets) == 1:
+            return TuxPutBucket(buckets[0])
+        # else, return None and force them to pick a bucket
+        return None
+    else:
+        if len(buckets) > 0:
+            return TuxPutBucket(buckets.pop())
+        else:
+            return None
 
 
 def verify_token(s3_handler, token, key):
@@ -111,7 +137,6 @@ def verify_token(s3_handler, token, key):
         """SELECT * from S3Object[*].users[*] u where u.token = '%s'""" % token
     )
     result = s3_handler.select_from_json(exp, key).pop()
-    print(result)
     return TuxUser(result)
 
 
